from functions import add, sub, mul, div
def cal():
   
   
    a = float(input("enter a value: "))
    b = float(input("enter b value: "))
   
    while True:
        try:
            optios = """

            1. add
            2. sub
            3. mul
            4. div
            5. stop
        
            """
            print(optios)
            user = int(input("enter ur num :"))
            if user == 1:
                data = add(a,b)
                print(data)
            elif user == 2:
                data = sub(a,b)
                print(data)
            elif user == 3:
                data = mul(a,b)
                print(data)
            elif user == 4:
                data = div(a,b)
                print(data)
            elif user == 5:
                break
        except Exception as e:
            raise e

# cal()


from setuptools import setup
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='hari_cal',
    version='0.0.2',
    description='Basic math',
    author= 'Phani Siginamsetty',
    # url = 'https://github.com/funnyPhani/Test_repo_rlms',
    # long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    keywords=["Oerations_in_math"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    py_modules=['hari_cal'],
    package_dir={'':'src'},
    install_requires = [
       "pandas"
    ]
)
